pub struct RightShoulderEntity(pub Compound);Tuple Fields
0: CompoundMethods from Deref<Target = Compound>
pub fn clear(&mut self)
pub fn get<Q>(&self, k: &Q) -> Option<&Value<S>>where
Q: AsBorrowed<S> + ?Sized,
<Q as AsBorrowed<S>>::Borrowed: Hash + Ord,
S: Borrow<<Q as AsBorrowed<S>>::Borrowed>,
pub fn contains_key<Q>(&self, k: &Q) -> boolwhere
Q: AsBorrowed<S> + ?Sized,
<Q as AsBorrowed<S>>::Borrowed: Hash + Ord,
S: Borrow<<Q as AsBorrowed<S>>::Borrowed>,
pub fn get_mut<Q>(&mut self, k: &Q) -> Option<&mut Value<S>>where
Q: AsBorrowed<S> + ?Sized,
<Q as AsBorrowed<S>>::Borrowed: Hash + Ord,
S: Borrow<<Q as AsBorrowed<S>>::Borrowed>,
pub fn get_key_value<Q>(&self, k: &Q) -> Option<(&S, &Value<S>)>where
Q: AsBorrowed<S> + ?Sized,
<Q as AsBorrowed<S>>::Borrowed: Hash + Ord,
S: Borrow<<Q as AsBorrowed<S>>::Borrowed>,
pub fn insert<K, V>(&mut self, k: K, v: V) -> Option<Value<S>>
pub fn remove<Q>(&mut self, k: &Q) -> Option<Value<S>>where
Q: AsBorrowed<S> + ?Sized,
<Q as AsBorrowed<S>>::Borrowed: Hash + Ord,
S: Borrow<<Q as AsBorrowed<S>>::Borrowed>,
pub fn swap_remove<Q>(&mut self, k: &Q) -> Option<Value<S>>where
Q: AsBorrowed<S> + ?Sized,
<Q as AsBorrowed<S>>::Borrowed: Hash + Ord,
S: Borrow<<Q as AsBorrowed<S>>::Borrowed>,
pub fn shift_remove<Q>(&mut self, k: &Q) -> Option<Value<S>>where
Q: AsBorrowed<S> + ?Sized,
<Q as AsBorrowed<S>>::Borrowed: Hash + Ord,
S: Borrow<<Q as AsBorrowed<S>>::Borrowed>,
pub fn remove_entry<Q>(&mut self, k: &Q) -> Option<(S, Value<S>)>
pub fn swap_remove_entry<Q>(&mut self, k: &Q) -> Option<(S, Value<S>)>
pub fn shift_remove_entry<Q>(&mut self, k: &Q) -> Option<(S, Value<S>)>
pub fn append(&mut self, other: &mut Compound<S>)
pub fn entry<K>(&mut self, k: K) -> Entry<'_, S>where
K: Into<S>,
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
pub fn iter(&self) -> Iter<'_, S>
pub fn iter_mut(&mut self) -> IterMut<'_, S>
pub fn keys(&self) -> Keys<'_, S>
pub fn values(&self) -> Values<'_, S>
pub fn values_mut(&mut self) -> ValuesMut<'_, S>
pub fn retain<F>(&mut self, f: F)
Sourcepub fn merge(&mut self, other: Compound<S>)
pub fn merge(&mut self, other: Compound<S>)
Inserts all items from other into self recursively.
Example
use chunkedge_nbt::compound;
let mut this = compound! {
"foo" => 10,
"bar" => compound! {
"baz" => 20,
}
};
let other = compound! {
"foo" => 15,
"bar" => compound! {
"quux" => "hello",
}
};
this.merge(other);
assert_eq!(
this,
compound! {
"foo" => 15,
"bar" => compound! {
"baz" => 20,
"quux" => "hello",
}
}
);Trait Implementations
Sourceimpl Clone for RightShoulderEntity
impl Clone for RightShoulderEntity
Sourcefn clone(&self) -> RightShoulderEntity
fn clone(&self) -> RightShoulderEntity
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Component for RightShoulderEntity
impl Component for RightShoulderEntity
Sourceconst STORAGE_TYPE: StorageType = bevy_ecs::component::StorageType::Table
const STORAGE_TYPE: StorageType = bevy_ecs::component::StorageType::Table
A constant indicating the storage type used for this component.
Sourcetype Mutability = Mutable
type Mutability = Mutable
A marker type to assist Bevy with determining if this component is
mutable, or immutable. Mutable components will have [
Component<Mutability = Mutable>],
while immutable components will instead have [Component<Mutability = Immutable>]. Read moreSourcefn register_required_components(
_requiree: ComponentId,
required_components: &mut RequiredComponentsRegistrator<'_, '_>,
)
fn register_required_components( _requiree: ComponentId, required_components: &mut RequiredComponentsRegistrator<'_, '_>, )
Registers required components. Read more
Sourcefn clone_behavior() -> ComponentCloneBehavior
fn clone_behavior() -> ComponentCloneBehavior
Called when registering this component, allowing to override clone function (or disable cloning altogether) for this component. Read more
Sourcefn relationship_accessor() -> Option<ComponentRelationshipAccessor<Self>>
fn relationship_accessor() -> Option<ComponentRelationshipAccessor<Self>>
Returns [
ComponentRelationshipAccessor] required for working with relationships in dynamic contexts. Read morefn on_add() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
fn on_add() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
Gets the
on_add [ComponentHook] for this [Component] if one is defined.fn on_insert() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
fn on_insert() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
Gets the
on_insert [ComponentHook] for this [Component] if one is defined.fn on_discard() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
fn on_discard() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
Gets the
on_discard [ComponentHook] for this [Component] if one is defined.fn on_remove() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
fn on_remove() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
Gets the
on_remove [ComponentHook] for this [Component] if one is defined.fn on_despawn() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
fn on_despawn() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
Gets the
on_despawn [ComponentHook] for this [Component] if one is defined.fn map_entities<E>(_this: &mut Self, _mapper: &mut E)where
E: EntityMapper,
fn map_entities<E>(_this: &mut Self, _mapper: &mut E)where
E: EntityMapper,
Maps the entities on this component using the given [
EntityMapper]. This is used to remap entities in contexts like scenes and entity cloning.
When deriving [Component], this is populated by annotating fields containing entities with #[entities] Read moreSourceimpl Debug for RightShoulderEntity
impl Debug for RightShoulderEntity
Sourceimpl Default for RightShoulderEntity
impl Default for RightShoulderEntity
Sourceimpl Deref for RightShoulderEntity
impl Deref for RightShoulderEntity
Sourceimpl DerefMut for RightShoulderEntity
impl DerefMut for RightShoulderEntity
Sourceimpl PartialEq for RightShoulderEntity
impl PartialEq for RightShoulderEntity
Sourcefn eq(&self, other: &RightShoulderEntity) -> bool
fn eq(&self, other: &RightShoulderEntity) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for RightShoulderEntity